package cn.com.infosec.jce;

import cn.com.infosec.asn1.DERConstructedSequence;
import cn.com.infosec.asn1.DERInputStream;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.jce.provider.X509CRLObjectFX;
import cn.com.infosec.jce.provider.X509CertificateObjectFX;
import cn.com.infosec.jce.provider.fastparser.DerUtil;
import cn.com.infosec.jce.provider.fastparser.FastPkcs7;
import cn.com.infosec.jce.provider.fastparser.Item;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.PrivateKey;
import java.security.Signature;
import java.security.cert.CRLException;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;

public class PKCS7SignedDataFX extends PKCS7SignedData {
   byte[] bsPKCS7;
   FastPkcs7 fxPKCS7;
   String provider;
   boolean isInvokedOldConstructMethod;

   public PKCS7SignedDataFX(byte[] in) {
      this(in, "INFOSEC");
   }

   private void invokedOldConstructMethod() {
      if (!this.isInvokedOldConstructMethod) {
         PKCS7SignedDataFX var10000 = this;
         PKCS7SignedDataFX var10001 = this;
         PKCS7SignedDataFX var10002 = this;
         byte[] var1 = this.bsPKCS7;
         var10001.PKCS7SignedData2(var1, var10002.provider);
         var10000.isInvokedOldConstructMethod = true;
      }
   }

   public PKCS7SignedDataFX(byte[] in, String provider) {
      this.bsPKCS7 = null;
      this.fxPKCS7 = null;
      this.provider = "";
      this.isInvokedOldConstructMethod = false;
      FastPkcs7 var3;
      FastPkcs7 var10002 = var3 = new FastPkcs7;
      var3.<init>();
      this.fxPKCS7 = var3;
      var10002.pkcs7SignedData(in);
      this.provider = provider;
      this.bsPKCS7 = in;
   }

   private DERObject getIssuer(byte[] enc) {
      IOException var10000;
      label32: {
         boolean var10001;
         DERConstructedSequence var8;
         try {
            var8 = (DERConstructedSequence)(new DERInputStream(new ByteArrayInputStream(enc))).readObject();
         } catch (IOException var4) {
            var10000 = var4;
            var10001 = false;
            break label32;
         }

         DERConstructedSequence var5 = var8;

         boolean var9;
         try {
            var9 = var8.getObjectAt(0) instanceof DERTaggedObject;
         } catch (IOException var3) {
            var10000 = var3;
            var10001 = false;
            break label32;
         }

         byte enc1;
         if (var9) {
            enc1 = 3;
         } else {
            enc1 = 2;
         }

         try {
            return (DERObject)var5.getObjectAt(enc1);
         } catch (IOException var2) {
            var10000 = var2;
            var10001 = false;
         }
      }

      IOException var6 = var10000;
      throw new Error("IOException reading from ByteArray: " + var6);
   }

   String getDigestAlgorithmExt() {
      return "";
   }

   String getDigestEncryptionAlgorithmExt() {
      return "";
   }

   public String getDigestAlgorithm() {
      String var1;
      String var10000 = var1 = this.fxPKCS7.getDigestAlgorithm();
      String var2 = this.fxPKCS7.getDigestEncryptionAlgorithm();
      if (var10000.equals("1.2.840.113549.2.5")) {
         var1 = "MD5";
      } else if (var1.equals("1.2.840.113549.2.2")) {
         var1 = "MD2";
      } else if (var1.equals("1.3.14.3.2.26")) {
         var1 = "SHA1";
      }

      if (var2.equals("1.2.840.113549.1.1.1")) {
         var2 = "RSA";
      } else if (var2.equals("1.2.840.10040.4.1")) {
         var2 = "DSA";
      }

      return var1 + "with" + var2;
   }

   public void reset() {
      PKCS7SignedDataFX var10000;
      try {
         var10000 = this;
         this.invokedOldConstructMethod();
      } catch (Exception var2) {
         throw new RuntimeException(var2.toString());
      }

      Exception var8;
      label35: {
         boolean var10001;
         PrivateKey var9;
         try {
            var9 = var10000.privKey;
         } catch (Exception var6) {
            var8 = var6;
            var10001 = false;
            break label35;
         }

         PrivateKey var1 = var9;
         if (var9 == null) {
            try {
               super.sig.initVerify(super.signCert.getPublicKey());
            } catch (Exception var5) {
               var8 = var5;
               var10001 = false;
               break label35;
            }
         } else {
            try {
               super.sig.initSign(var1);
            } catch (Exception var4) {
               var8 = var4;
               var10001 = false;
               break label35;
            }
         }

         try {
            return;
         } catch (Exception var3) {
            var8 = var3;
            var10001 = false;
         }
      }

      Exception var7 = var8;
      throw new RuntimeException(var7.toString());
   }

   public Certificate[] getCertificates() {
      Collection var1;
      if ((var1 = super.certs) == null || var1.size() == 0) {
         ArrayList var7 = this.fxPKCS7.getCerts();
         super.certs = new ArrayList();

         for(int var2 = 0; var2 < var7.size(); ++var2) {
            Item var3;
            int var4;
            int var5;
            byte[] var6 = new byte[var5 = (var3 = (Item)var7.get(var2)).length + (var4 = var3.tagsize)];
            System.arraycopy(this.bsPKCS7, var3.offset - var4, var6, 0, var5);
            super.certs.add(new X509CertificateObjectFX(var6));
         }
      }

      return (X509Certificate[])super.certs.toArray(new X509Certificate[0]);
   }

   public Collection getCRLs() {
      Collection var1;
      if ((var1 = super.crls) == null || var1.size() == 0) {
         ArrayList var8 = this.fxPKCS7.getCrls();
         super.crls = new ArrayList();

         for(int var2 = 0; var2 < var8.size(); ++var2) {
            PKCS7SignedDataFX var10000 = this;
            Item var3;
            int var4;
            int var5;
            byte[] var6 = new byte[var5 = (var3 = (Item)var8.get(var2)).length + (var4 = var3.tagsize)];
            System.arraycopy(this.bsPKCS7, var3.offset - var4, var6, 0, var5);

            try {
               var10000.crls.add(new X509CRLObjectFX(var6));
            } catch (CRLException var7) {
               var7.printStackTrace();
            }
         }
      }

      return super.crls;
   }

   public X509Certificate getSigningCertificate() {
      if (super.signCert == null) {
         Item var1 = this.fxPKCS7.getSignCert();
         byte[] var2 = DerUtil.getItemDataAndTag(this.bsPKCS7, var1);
         super.signCert = new X509CertificateObjectFX(var2);
      }

      return super.signCert;
   }

   public int getVersion() {
      return super.version = this.fxPKCS7.getVersion();
   }

   public int getSigningInfoVersion() {
      return super.signerversion = this.fxPKCS7.getSignInfoVersion();
   }

   public byte[] getContentData() {
      if (super.contentData == null) {
         Item var1 = this.fxPKCS7.getRawData();
         super.contentData = DerUtil.getItemData(this.bsPKCS7, var1);
      }

      return super.contentData;
   }

   public boolean verify() {
      if (super.digest == null) {
         Item var1 = this.fxPKCS7.getDigest();
         super.digest = DerUtil.getItemData(this.bsPKCS7, var1);
      }

      NoSuchProviderException var10000;
      label53: {
         InvalidKeyException var10;
         label54: {
            NoSuchAlgorithmException var9;
            label42: {
               PKCS7SignedDataFX var11;
               PKCS7SignedDataFX var12;
               boolean var10001;
               X509Certificate var10002;
               try {
                  var11 = this;
                  var12 = this;
                  super.sig = Signature.getInstance(this.getDigestAlgorithm(), this.provider);
                  var10002 = this.getSigningCertificate();
               } catch (InvalidKeyException var5) {
                  var10 = var5;
                  var10001 = false;
                  break label54;
               } catch (NoSuchAlgorithmException var6) {
                  var9 = var6;
                  var10001 = false;
                  break label42;
               } catch (NoSuchProviderException var7) {
                  var10000 = var7;
                  var10001 = false;
                  break label53;
               }

               X509Certificate var8 = var10002;

               try {
                  var12.signCert = var10002;
                  var11.sig.initVerify(var8.getPublicKey());
                  return super.sig.verify(super.digest);
               } catch (InvalidKeyException var2) {
                  var10 = var2;
                  var10001 = false;
                  break label54;
               } catch (NoSuchAlgorithmException var3) {
                  var9 = var3;
                  var10001 = false;
               } catch (NoSuchProviderException var4) {
                  var10000 = var4;
                  var10001 = false;
                  break label53;
               }
            }

            var9.printStackTrace();
            return super.sig.verify(super.digest);
         }

         var10.printStackTrace();
         return super.sig.verify(super.digest);
      }

      var10000.printStackTrace();
      return super.sig.verify(super.digest);
   }

   public byte[] getEncoded() {
      return this.bsPKCS7;
   }
}
